@@ -4,7 +4,7 @@ use strict;
 #
 # crlpublish
 #
-# Copyright (C) 2014, Kevin Cody-Little <kcodyjr@gmail.com>
+# Copyright (C) 2014, Kevin Cody-Little <kcody@cpan.org>
 #
 # Portions derived from crlpublisher.sh, original copyright follows:
 #
@@ -24,74 +24,54 @@ use strict;
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 ###############################################################################
-# Global Configuration
 
-our $VERSION = '0.3';
+=head1 NAME
 
-my @runpath = split /\//, $0;
-my $program = pop @runpath;
+EJBCA::CrlPublish::Run
+
+=head1 SYNOPSIS
+
+Implements the /usr/bin/crlpublish script.
+
+=head1 PREFERRED INVOCATION
+
+=head2 /usr/bin/crlpublish [arguments]
+
+=head1 ALTERNATE INVOCATION
+
+=head2 perl -e 'use EJBCA::CrlPublish::Run' [arguments]
+
+=head1 DEVELOPER NOTES
+
+Since it implements an executable script, this module must control the exit
+value, and therefore would interrupt startup if included by "use" or
+"require" in another program.
+
+To publish from within another program, use EJBCA::CrlPublish instead.
+
+=cut
 
 
 ###############################################################################
-# Forward Function Declarations
+# Library Dependencies
 
 use EJBCA::CrlPublish;
 
-sub usage();
-sub version();
+our $VERSION = '0.4';
 
 
 ###############################################################################
-# Argument Processing
+# Display Messages
 
-if ( @ARGV == 0 ) {
-
-	unless ( -t STDIN ) {
-		EJBCA::CrlPublish::processQueue;
-		exit -1; # should not return
-	}
-
-	usage;
-	exit 0;
-}
-
-elsif ( @ARGV == 1 ) {
-
-	if ( -f $ARGV[0] ) {	# called with a crl
-		EJBCA::CrlPublish::processCrl( $ARGV[0] );
-		exit -1; # should not return
-	}
-
-	elsif ( $ARGV[0] eq '-v' ) {
-		version;
-		exit 0;
-	}
-
-	elsif ( $ARGV[0] eq '-h' ) {
-		usage;
-		exit 0;
-	}
-
-	else {
-		usage;
-		exit 1;
-	}
-}
-
-else {
-	usage;
-	exit 1;
-}
-
-
-###############################################################################
-# copyright message
+{ # private lexicals begin
+my @runpath = split /\//, $0;
+my $program = pop @runpath;
 
 sub version() {
 	print $program , ', version ', $VERSION, "\n";
-	print q%
+	print '
 +-----------------------------------------------------------------------+
-| Copyright (C) 2014, Kevin Cody-Little <kcodyjr@gmail.com>             |
+| Copyright (C) 2014, Kevin Cody-Little <kcody@cpan.org>                |
 | Copyright (C) 2011, Branko Majic <branko@majic.rs>                    |
 |                                                                       |
 | This program is free software: you can redistribute it and/or modify  |
@@ -108,15 +88,100 @@ sub version() {
 | along with this program.  If not, see <http://www.gnu.org/licenses/>. |
 +-----------------------------------------------------------------------+
 
-%
+'
+}
+
+sub usage() {
+	print $program , ', version ', $VERSION, "\n";
+	print <<EEOF
+Usage: $program <crlFile>
+       $program -q | -l | -v | -h
+
+$program is a utility for publishing certificate revocation lists to their
+issuing distribution points. If called with the path to a CRL file in either
+DER or PEM format as its only argument, it will publish that CRL to one or
+more target servers.
+
+$program references configuration files to determine where to send any given
+CRL, by what method to send it, and with what parameters. The configuration
+file format and location is detailed in "man crlpublish".
+
+$program is fully backwards compatible with the configuration files from
+Branko Majik's crlpublisher.sh script version 0.1, in situ and as-is.
+
+If no configuration files exist, $program will use the "scp" method, will
+try to retrieve the publishing host, path, and filename from the CRL itself,
+will use the default SSH private keys, and will use the same username on
+the target as on the origin host.
+
+(TODO) $program is capable of queuing CRLs for asynchronous transfer. If
+called with the "-l" argument, $program will list the contents of the queue.
+If called with "-q", $program will try to flush the contents of the queue.
+
+Also, the queue will be flushed if $program is called with no arguments and
+STDIN is not a terminal. This is for convenience in setting up cron jobs.
+
+EEOF
+}
+
+} # private lexicals end
+
+
+###############################################################################
+# Command Line Processing
+
+if ( @ARGV == 0 ) {
+
+	unless ( -t STDIN ) {
+		EJBCA::CrlPublish::processQueue;
+		exit -1;	# should not return
+	}
+
+	usage;
+	exit 0;
+}
+
+elsif ( @ARGV == 1 ) {
+
+	if ( -f $ARGV[0] ) {	# called with a crl
+		EJBCA::CrlPublish::publishCrl( $ARGV[0] );
+		exit -1;	# should not return
+	}
+
+	elsif ( $ARGV[0] eq '-v' ) {
+		version;
+		exit 0;
+	}
+
+	elsif ( $ARGV[0] eq '-h' ) {
+		usage;
+		exit 0;
+	}
+
+	elsif ( $ARGV[0] eq '-q' ) {
+		EJBCA::CrlPublish::processQueue;
+		exit -1;	# should not return
+	}
+
+	else {
+		usage;
+		exit 1;
+	}
+}
+
+else {
+	usage;
+	exit 1;
 }
 
 
 ###############################################################################
-# usage message
 
-sub usage() {
-}
+=head1 AUTHOR
+
+Kevin Cody-Little <kcody@cpan.org>
+
+=cut
 
 
 ###############################################################################
